==> pepperize.cdk-serverless-cluster-from-snapshot-0.0.8.tar.gz: package/README.md <==
[![GitHub](https://img.shields.io/github/license/pepperize/cdk-serverless-cluster-from-snapshot?style=flat-square)](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/blob/main/LICENSE)
[![npm (scoped)](https://img.shields.io/npm/v/@pepperize/cdk-serverless-cluster-from-snapshot?style=flat-square)](https://www.npmjs.com/package/@pepperize/cdk-serverless-cluster-from-snapshot)
[![PyPI](https://img.shields.io/pypi/v/pepperize.cdk-serverless-cluster-from-snapshot?style=flat-square)](https://pypi.org/project/pepperize.cdk-serverless-cluster-from-snapshot/)
[![Nuget](https://img.shields.io/nuget/v/Pepperize.CDK.ServerlessClusterFromSnapshot?style=flat-square)](https://www.nuget.org/packages/Pepperize.CDK.ServerlessClusterFromSnapshot/)
[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/pepperize/cdk-serverless-cluster-from-snapshot/release/main?label=release&style=flat-square)](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/actions/workflows/release.yml)
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/pepperize/cdk-serverless-cluster-from-snapshot?sort=semver&style=flat-square)](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/releases)

# AWS RDS Aurora serverless cluster from snapshot

This project provides a CDK construct creating a serverless database cluster from a snapshot with AWS RDS Aurora engine.

See [API.md](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/blob/main/API.md)

==> pepperize.cdk-serverless-cluster-from-snapshot-0.0.45.tar.gz: package/README.md <==
[![GitHub](https://img.shields.io/github/license/pepperize/cdk-serverless-cluster-from-snapshot?style=flat-square)](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/blob/main/LICENSE)
[![npm (scoped)](https://img.shields.io/npm/v/@pepperize/cdk-serverless-cluster-from-snapshot?style=flat-square)](https://www.npmjs.com/package/@pepperize/cdk-serverless-cluster-from-snapshot)
[![PyPI](https://img.shields.io/pypi/v/pepperize.cdk-serverless-cluster-from-snapshot?style=flat-square)](https://pypi.org/project/pepperize.cdk-serverless-cluster-from-snapshot/)
[![Nuget](https://img.shields.io/nuget/v/Pepperize.CDK.ServerlessClusterFromSnapshot?style=flat-square)](https://www.nuget.org/packages/Pepperize.CDK.ServerlessClusterFromSnapshot/)
[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/pepperize/cdk-serverless-cluster-from-snapshot/release/main?label=release&style=flat-square)](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/actions/workflows/release.yml)
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/pepperize/cdk-serverless-cluster-from-snapshot?sort=semver&style=flat-square)](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/releases)

# AWS RDS Aurora serverless cluster from snapshot

This project provides a CDK construct creating a serverless database cluster from a snapshot with AWS RDS Aurora engine.

See [API.md](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/blob/main/API.md)

## Install

### TypeScript

```shell
npm install @pepperize/cdk-serverless-cluster-from-snapshot
```

or

```shell
yarn add @pepperize/cdk-serverless-cluster-from-snapshot
```

### Python

```shell
pip install pepperize.cdk-serverless-cluster-from-snapshot
```

### C# / .Net

```
dotnet add package Pepperize.CDK.ServerlessClusterFromSnapshot
```
